@@ -51,7 +51,7 @@ test -d $HOME/MyDocs || ln -s /home/user/MyDocs $HOME/MyDocs
 test -d $HOME/bin || mkdir $HOME/bin
 devown $HOME/bin
 
-for b in devrootsh # remote-wrapper.sh utfs-client
+for b in devrootsh remote-wrapper.sh utfs-client
 do
     test -f $HOME/bin/$b || ln -s $libdir/$b $HOME/bin
 done
