@@ -1,4 +1,5 @@
 #include <QGridLayout>
+#include <QStackedWidget>
 #include <QLineEdit>
 #include <QLabel>
 #include <QPushButton>
@@ -6,6 +7,7 @@
 #include <QStringList>
 #include <QValidator>
 #include <QCheckBox>
+#include <QComboBox>
 
 #include "mainwindow.h"
 #include "editinterface.h"
@@ -118,32 +120,47 @@ EditInterface::EditInterface(MainWindow *main, ProcessRunner *runner)
 	IP4Validator *ipvtor = new IP4Validator;
 	IP4MaskValidator *maskvtor = new IP4MaskValidator;
 
-	m_ipaddress = new QLabel(tr("IP Address:    "));
+	m_ipaddress = new QLabel(tr("IP Address:"));
 	m_iptxt = new QLineEdit(tr("192.168.2.15"));
 	m_iptxt->setFrame(false);
 	m_iptxt->setValidator(ipvtor);
 	m_iptxt->setMaxLength(15);
 	m_iptxt->setStyleSheet(default_color);
 
-	m_netmask = new QLabel(tr("Netmask:       "));
+	m_netmask = new QLabel(tr("Netmask:"));
 	m_masktxt = new QLineEdit(tr("255.255.255.0"));
 	m_masktxt->setFrame(false);
 	m_masktxt->setValidator(maskvtor);
 	m_masktxt->setMaxLength(15);
 	m_masktxt->setStyleSheet(default_color);
 
-	m_route = new QCheckBox(tr("Default route"));
+	m_stack = new QStackedWidget();
+	/*
+	 * Extra spaces because of txt cannot been fully seen on N900
+	 */
+	m_route = new QCheckBox(tr("Default Route:  "));
 	m_route->setTristate(false);
 
+	m_peerip = new QLabel(tr("Peer IP:"));
+	m_defroute = new QLabel(tr("Default Route:"));
+
+	m_stack->addWidget(m_route);
+	m_stack->addWidget(m_peerip);
+	m_stack->addWidget(m_defroute);
+	m_stack->setCurrentIndex(1);
+
 	m_gwtxt = new QLineEdit(tr("192.168.2.14"));
 	m_gwtxt->setFrame(false);
 	m_gwtxt->setValidator(ipvtor);
 	m_gwtxt->setMaxLength(15);
-	m_gwtxt->setReadOnly(true);
-	m_gwtxt->setStyleSheet(readonly_color);
+	m_gwtxt->setReadOnly(false);
+	m_gwtxt->setStyleSheet(default_color);
 
-	m_dhcp = new QCheckBox(tr("use Dhcp"));
-	m_dhcp->setTristate(false);
+	m_dhcp = new QComboBox();
+	m_dhcp->addItem("DHCP server");
+	m_dhcp->addItem("DHCP client");
+	m_dhcp->addItem("Static");
+	m_dhcp->setMaxCount(3);
 
 	m_configure = new QPushButton(tr("Configure"));
 	m_cancel = new QPushButton(tr("Cancel"));
@@ -155,17 +172,18 @@ EditInterface::EditInterface(MainWindow *main, ProcessRunner *runner)
 	m_layout->addWidget(m_netmask,   1, 0, Qt::AlignLeft);
 	m_layout->addWidget(m_masktxt,   1, 1, Qt::AlignLeft);
 
-	m_layout->addWidget(m_route,     2, 0, Qt::AlignLeft);
+	m_layout->addWidget(m_stack,     2, 0, Qt::AlignLeft);
+	//m_layout->addWidget(m_route,     2, 0, Qt::AlignLeft);
 	m_layout->addWidget(m_gwtxt,     2, 1, Qt::AlignLeft);
 
-	m_layout->addWidget(m_dhcp,      0, 2);
+	m_layout->addWidget(m_dhcp,      0, 2, Qt::AlignLeft);
 
 	m_layout->addWidget(m_cancel,    1, 2);
 	m_layout->addWidget(m_configure, 2, 2);
 
-	m_layout->setRowStretch(3, 1);
+	m_layout->setRowStretch(2, 1);
 
-	connect(m_dhcp, SIGNAL(stateChanged(int)),
+	connect(m_dhcp, SIGNAL(activated(int)),
 		this, SLOT(toggleDhcp(int)));
 	connect(m_route, SIGNAL(stateChanged(int)),
 		this, SLOT(toggleRoute(int)));
@@ -174,12 +192,14 @@ EditInterface::EditInterface(MainWindow *main, ProcessRunner *runner)
 }
 
 void
-EditInterface::configure(void)
+EditInterface::configure0()
 {
 	QString name("./interfaces.sh");
 	QStringList args(QString("usb0"));
 
-	if (m_dhcp->checkState() == Qt::Unchecked) {
+	if (m_dhcp->currentIndex() == DHCP_CLIENT) {
+		args.append("dhcp");
+	} else if (m_dhcp->currentIndex() == DHCP_STATIC) {
 		if (!m_iptxt->hasAcceptableInput()) {
 			// TODO popup
 			return ;
@@ -190,6 +210,7 @@ EditInterface::configure(void)
 			return ;
 		}
 
+		args.append("static");
 		args.append(m_iptxt->text());
 		args.append(m_masktxt->text());
 
@@ -200,24 +221,37 @@ EditInterface::configure(void)
 			}
 			args.append(m_gwtxt->text());
 		}
+	} else if (m_dhcp->currentIndex() == DHCP_SERVER) {
+		if (!m_iptxt->hasAcceptableInput()) {
+			// TODO popup
+			return ;
+		}
+
+		if (!m_masktxt->hasAcceptableInput()) {
+			// TODO popup
+			return ;
+		}
+
+		args.append("dhcpd");
+		args.append(m_iptxt->text());
+		args.append(m_masktxt->text());
+		args.append(m_gwtxt->text());
 	}
 
 	m_runner->start(name, args);
+}
 
+void
+EditInterface::configure()
+{
+	configure0();
 	m_main->showLauncher();
 }
 
 void
 EditInterface::toggleDhcp(int state)
 {
-	if (state == Qt::Checked) {
-		m_iptxt->setReadOnly(true);
-		m_masktxt->setReadOnly(true);
-		m_gwtxt->setReadOnly(true);
-		m_iptxt->setStyleSheet(readonly_color);
-		m_masktxt->setStyleSheet(readonly_color);
-		m_gwtxt->setStyleSheet(readonly_color);
-	} else {
+	if (state == DHCP_STATIC) {
 		m_iptxt->setReadOnly(false);
 		m_masktxt->setReadOnly(false);
 		m_iptxt->setStyleSheet(default_color);
@@ -225,14 +259,34 @@ EditInterface::toggleDhcp(int state)
 		if (m_route->checkState() == Qt::Checked) {
 			m_gwtxt->setStyleSheet(default_color);
 			m_gwtxt->setReadOnly(false);
+		} else {
+			m_gwtxt->setStyleSheet(readonly_color);
+			m_gwtxt->setReadOnly(true);
 		}
+		m_stack->setCurrentIndex(0);
+	} else if (state == DHCP_SERVER) {
+		m_iptxt->setReadOnly(false);
+		m_masktxt->setReadOnly(false);
+		m_iptxt->setStyleSheet(default_color);
+		m_masktxt->setStyleSheet(default_color);
+		m_gwtxt->setStyleSheet(default_color);
+		m_gwtxt->setReadOnly(false);
+		m_stack->setCurrentIndex(1);
+	} else if (state == DHCP_CLIENT) {
+		m_iptxt->setReadOnly(true);
+		m_masktxt->setReadOnly(true);
+		m_gwtxt->setReadOnly(true);
+		m_iptxt->setStyleSheet(readonly_color);
+		m_masktxt->setStyleSheet(readonly_color);
+		m_gwtxt->setStyleSheet(readonly_color);
+		m_stack->setCurrentIndex(2);
 	}
 }
 
 void
 EditInterface::toggleRoute(int state)
 {
-	if (m_dhcp->checkState() == Qt::Checked)
+	if (m_dhcp->currentIndex() != DHCP_STATIC)
 		return ;
 
 	if (state == Qt::Checked) {
